/// <reference types="undertaker" />
import { DependencyMap } from '../model/dependency-map';
import { BuildMode } from '../model/build-mode';
import { PackerOptions } from '../model/packer-options';
import { PackageConfig } from '../model/package-config';
import { Logger } from '../common/logger';
import { TestEnvironment } from '../model/test-environment';
/**
 * Parse package dependency map mode.
 * @param packerOptions Packer options object.
 */
export declare const parseDependencyMapMode: (packerOptions: PackerOptions) => DependencyMap;
/**
 * Parse package bundle format.
 * @param packerOptions Packer options object.
 */
export declare const parseBundleFormat: (packerOptions: PackerOptions) => "cjs" | "esm" | "umd" | "amd" | "iife" | "system";
/**
 * Generate and copy packer configuration file.
 * @param packerOptions Packer options object.
 * @param scriptExt Script file extension.
 * @param buildMode Package build mode.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 */
export declare const copyPackerConfig: (packerOptions: PackerOptions, scriptExt: string, buildMode: BuildMode, testEnvironment: TestEnvironment, projectDir: string) => import("undertaker").TaskFunction;
/**
 * Copy license file.
 * @param packerOptions Packer options object.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const licenseCopy: (packerOptions: PackerOptions, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy readme.md file.
 * @param packageConfig Package configuration object.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyReadme: (packageConfig: PackageConfig, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy babel configuration.
 * @param packerOptions Packer options object.
 * @param buildMode Project build mode.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyBabelConfig: (packerOptions: PackerOptions, buildMode: BuildMode, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy gitignore file.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyGitIgnore: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy packer asset (banner.hbs and bin.hbs) files.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyPackerAssets: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy typescript configuration tsconfig.json and tslint.json files.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyTypescriptConfig: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy postcss configuration file.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyPostCssConfig: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy ESLint configuration file.
 * @param packerOptions Packer options object reference.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyEsLintConfig: (packerOptions: PackerOptions, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy style lint configuration file.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyStyleLintConfig: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy common configuration (package.json, .editorconfig and travis.yml) files
 * @param packageConfig Package configuration object.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyCommonConfig: (packageConfig: PackageConfig, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy prettier configuration file.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyPrettierConfig: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Get project configuration file generation gulp tasks.
 * @param packerOptions Packer configuration object.
 * @param packageConfig Package configuration object.
 * @param buildMode Project build mode.
 * @param scriptExt Script file extension.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const getConfigFileGenerateTasks: (packerOptions: PackerOptions, packageConfig: PackageConfig, buildMode: BuildMode, scriptExt: string, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction[];
