/// <reference types="undertaker" />
import { Logger } from '../common/logger';
import { PackerOptions } from '../model/packer-options';
import { TestEnvironment } from '../model/test-environment';
/**
 * Parse script transpiler by preprocessor type and extract extension glob depending on enzyme support.
 * @param packerOptions Packer options object.
 * @param scriptExt Script file extension.
 */
export declare const parseSpecScriptExtension: (packerOptions: PackerOptions, scriptExt: string) => string;
/**
 * Copy jasmine configuration file.
 * @param packerOptions Packer options object.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJasmineConfig: (packerOptions: PackerOptions, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jasmine helper script files.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJasmineHelpers: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jasmine test spec files.
 * @param scriptGlob Script extension glob.
 * @param scriptExt Script file extension.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJasmineSpec: (scriptGlob: string, scriptExt: string, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy karma jasmine test spec files.
 * @param scriptGlob Script extension glob.
 * @param scriptExt Script file extension.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyKarmaJasmineSpec: (scriptGlob: string, scriptExt: string, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jasmine configuration file.
 * @param packerOptions Packer options object.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyMochaConfig: (packerOptions: PackerOptions, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy mocha helper script files. Used as mocha require scripts.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyMochaHelpers: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy mocha test spec files.
 * @param scriptGlob Script extension glob.
 * @param scriptExt Script file extension.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyMochaTestSpec: (scriptGlob: string, scriptExt: string, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy karma mocha test spec files.
 * @param scriptExt Script file extension.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyKarmaMochaTestSpec: (scriptExt: string, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jest configuration file.
 * @param packerOptions Packer options object.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJestConfig: (packerOptions: PackerOptions, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jest mock scripts.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJestMockScripts: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy jest test files.
 * @param scriptGlob Script extension glob.
 * @param scriptExt Script file extension.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyJestTests: (scriptGlob: string, scriptExt: string, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy test typescript configuration (tsconfig.test.json) file.
 * @param packerOptions Packer options object reference.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyTestTypescriptConfig: (packerOptions: PackerOptions, projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Copy karma configuration (karma.conf.js) file.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const copyKarmaConfig: (projectDir: string, log: Logger) => import("undertaker").TaskFunction;
/**
 * Get test specification generator gulp task functions.
 * @param packerOptions Packer options object.
 * @param scriptExt Script file extension.
 * @param testEnvironment Test environment type.
 * @param projectDir Project root directory.
 * @param log Logger reference.
 */
export declare const getTestSpecGeneratorTasks: (packerOptions: PackerOptions, scriptExt: string, testEnvironment: TestEnvironment, projectDir: string, log: Logger) => import("undertaker").TaskFunction[];
