import { Logger } from '../common/logger';
export declare const args: string[];
/**
 * Run shell command in node environment.
 * @param command Shell command with arguments.
 * @param dir Execution dir.
 * @param log Logger reference.
 */
export declare const runShellCommand: (command: string, dir: string, log: Logger) => Promise<unknown>;
/**
 * Make relative directory path by fragments.
 * Create none existing fragments and ignore existing.
 * @param fragments Directory path fragments.
 */
export declare const makeRelativeDirPath: (...fragments: string[]) => void;
/**
 * Write file async.
 * @param filePath Path to write the file.
 * @param data Data to include in the file being written.
 */
export declare const writeFile: (filePath: string, data: any) => Promise<void>;
/**
 * Read file async.
 * @param filePath Path to read the file from.
 */
export declare const readFile: (filePath: string) => Promise<string>;
/**
 * Read configuration file sync.
 * @param filePath File path.
 */
export declare const readConfigFile: <T>(filePath: string) => T;
/**
 * Merge objects deep.
 * @param object Base object.
 * @param sources Source objects to merge.
 */
export declare const mergeDeep: (object: any, ...sources: any[]) => any;
/**
 * Watch source for changes and execute callback function
 * @param watchPath Watch path or paths glob collection.
 * @param callback Callback function to execute on change
 */
export declare const watchSource: (watchPath: string | string[], callback: () => Promise<void>) => Promise<void>;
/**
 * Import peer dependencies dynamically on runtime.
 * @param module Module name.
 * @param log Logger reference.
 */
export declare const requireDependency: (module: string, log: Logger) => any;
