import { Logger } from '../common/logger';
import { PackerConfig } from '../model/packer-config';
/**
 * Schema inspector packer config validation schema.
 */
export declare const packerSchema: {
    type: string;
    optional: boolean;
    $mapDef: boolean;
    properties: {
        entry: {
            type: string;
            optional: boolean;
            def: string;
        };
        source: {
            type: string;
            optional: boolean;
            def: string;
        };
        dist: {
            type: string;
            optional: boolean;
            def: string;
        };
        tmp: {
            type: string;
            optional: boolean;
            def: string;
        };
        compiler: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                dependencyMapMode: {
                    type: string;
                    optional: boolean;
                    def: string;
                    pattern: RegExp;
                };
                packageFieldsToCopy: {
                    type: string;
                    optional: boolean;
                    def: string[];
                    items: {
                        type: string;
                    };
                };
                sourceMap: {
                    type: string[];
                    optional: boolean;
                    pattern: RegExp;
                    def: boolean;
                };
                customRollupPluginExtractor: {
                    type: string[];
                    optional: boolean;
                    def: any;
                };
                build: {
                    type: string;
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        bundleMin: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                        es5: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                        es5Min: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                        esnext: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                        esnextMin: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                    };
                };
                buildMode: {
                    type: string;
                    optional: boolean;
                    def: string;
                    pattern: RegExp;
                };
                script: {
                    type: string;
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        preprocessor: {
                            type: string;
                            optional: boolean;
                            def: string;
                            pattern: RegExp;
                        };
                        tsd: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                        image: {
                            type: string;
                            optional: boolean;
                            $mapDef: boolean;
                            properties: {
                                inlineLimit: {
                                    type: string;
                                    optional: boolean;
                                    gt: number;
                                    def: number;
                                };
                                outDir: {
                                    type: string;
                                    optional: boolean;
                                    def: string;
                                };
                            };
                        };
                    };
                };
                style: {
                    type: string[];
                    optional: boolean;
                    $acceptOnly: string;
                    $mapDef: boolean;
                    properties: {
                        inline: {
                            type: string;
                            optional: boolean;
                            def: boolean;
                        };
                        outDir: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                        preprocessor: {
                            type: string;
                            optional: boolean;
                            def: string;
                            pattern: RegExp;
                        };
                        image: {
                            type: string;
                            optional: boolean;
                            $mapDef: boolean;
                            properties: {
                                inlineLimit: {
                                    type: string;
                                    optional: boolean;
                                    gt: number;
                                    def: number;
                                };
                                outDir: {
                                    type: string;
                                    optional: boolean;
                                    def: string;
                                };
                            };
                        };
                    };
                };
                concurrentBuild: {
                    type: string;
                    optional: boolean;
                    def: boolean;
                };
                advanced: {
                    type: string;
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        rollup: {
                            type: string;
                            optional: boolean;
                            $mapDef: boolean;
                            properties: {
                                inputOptions: {
                                    type: string;
                                    optional: boolean;
                                    def: {};
                                };
                                outputOptions: {
                                    type: string;
                                    optional: boolean;
                                    def: {};
                                };
                                watchOptions: {
                                    type: string;
                                    optional: boolean;
                                    def: {};
                                };
                                pluginOptions: {
                                    type: string;
                                    optional: boolean;
                                    $mapDef: boolean;
                                    properties: {
                                        ignoreImport: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        postCss: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        nodeResolve: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        commonjs: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        json: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        globals: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        babel: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        typescript: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        replace: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        image: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        handlebars: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        filesize: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                        browserSync: {
                                            type: string;
                                            optional: boolean;
                                            def: {};
                                        };
                                    };
                                };
                            };
                        };
                        other: {
                            type: string;
                            optional: boolean;
                            $mapDef: boolean;
                            properties: {
                                terser: {
                                    type: string;
                                    optional: boolean;
                                    def: {};
                                };
                                cssnano: {
                                    type: string;
                                    optional: boolean;
                                    def: {};
                                };
                            };
                        };
                    };
                };
            };
        };
        assetPaths: {
            type: string;
            optional: boolean;
            items: {
                type: string;
            };
            def: any[];
        };
        copy: {
            type: string;
            optional: boolean;
            items: {
                type: string;
            };
            def: string[];
        };
        ignore: {
            type: string;
            optional: boolean;
            items: {
                type: string;
            };
            def: any[];
        };
        replacePatterns: {
            type: string;
            optional: boolean;
            items: {
                type: string;
                properties: {
                    include: {
                        type: string[];
                        optional: boolean;
                        items: {
                            type: string;
                        };
                    };
                    exclude: {
                        type: string[];
                        optional: boolean;
                        items: {
                            type: string;
                        };
                    };
                    test: {
                        type: string[];
                        optional: boolean;
                    };
                    replace: {
                        type: string;
                        optional: boolean;
                    };
                    match: {
                        type: string;
                        optional: boolean;
                    };
                    text: {
                        type: string;
                        optional: boolean;
                    };
                    file: {
                        type: string;
                        optional: boolean;
                    };
                    pathReplaceCallback: {
                        type: string;
                        optional: boolean;
                    };
                };
            };
            def: any[];
        };
        bundle: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                externals: {
                    type: string;
                    optional: boolean;
                    items: {
                        type: string;
                    };
                    def: any[];
                };
                globals: {
                    type: string;
                    optional: boolean;
                };
                mapExternals: {
                    type: string;
                    optional: boolean;
                    def: boolean;
                };
                format: {
                    type: string;
                    optional: boolean;
                    def: string;
                    pattern: RegExp;
                };
                namespace: {
                    type: string;
                    optional: boolean;
                    def: string;
                };
                amd: {
                    type: string;
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        define: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                        id: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                    };
                };
            };
        };
        test: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                framework: {
                    type: string;
                    optional: boolean;
                    def: string;
                    pattern: RegExp;
                };
                environment: {
                    type: string;
                    optional: boolean;
                    def: string;
                    pattern: RegExp;
                };
                advanced: {
                    type: string;
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        jasmine: {
                            default: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            watch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageDefault: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageWatch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                        };
                        mocha: {
                            default: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            watch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageDefault: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageWatch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                        };
                        jest: {
                            default: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            watch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageDefault: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                            coverageWatch: {
                                type: string;
                                optional: boolean;
                                def: string;
                            };
                        };
                    };
                };
            };
        };
        serve: {
            type: string[];
            optional: boolean;
            $acceptOnly: string;
            $mapDef: boolean;
            properties: {
                demoDir: {
                    type: string;
                    optional: boolean;
                    def: string;
                };
                helperDir: {
                    type: string;
                    optional: boolean;
                    def: string;
                };
                serveDir: {
                    type: string;
                    optional: boolean;
                    items: {
                        type: string;
                    };
                    def: any[];
                };
                open: {
                    type: string;
                    optional: boolean;
                    def: boolean;
                };
                port: {
                    type: string;
                    optional: boolean;
                    gt: number;
                    lt: number;
                    def: number;
                };
            };
        };
        license: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                banner: {
                    type: string;
                    optional: boolean;
                    def: boolean;
                };
            };
        };
        format: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                extensions: {
                    type: string;
                    optional: boolean;
                    def: string[];
                    items: {
                        type: string;
                    };
                };
                advanced: {
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        command: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                    };
                };
            };
        };
        lint: {
            type: string;
            optional: boolean;
            $mapDef: boolean;
            properties: {
                advanced: {
                    optional: boolean;
                    $mapDef: boolean;
                    properties: {
                        style: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                        typescript: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                        javascript: {
                            type: string;
                            optional: boolean;
                            def: string;
                        };
                    };
                };
            };
        };
    };
};
/**
 * Cross validate configuration of dependent config errors.
 * @param packerConfig Packer configuration reference.
 * @param log Logger reference.
 */
export declare const crossValidateConfig: (packerConfig: PackerConfig, log: Logger) => void;
